.. _introduction:

************
Introduction
************

.. warning::

    This documentation is a work-in-progress.


The candig-server is a CanDIG project, aiming to provide distributed, secure data access
to participating institutions across Canada. You can learn more about our work from
https://www.distributedgenomics.ca

It has been built on the `ga4gh-server <https://github.com/ga4gh/ga4gh-server/>`_ with
extended functionalities including native support for peer-to-peer communications, clinical
and pipeline metadata support, as well as the upgraded codebase, written in Python 3.